---
title: Install xjs on Arch Linux using the Snap Store | Snapcraft
description: Get the latest version of xjs for on Arch Linux - A tool to parse juju
  status yaml/json files offline
url: https://snapcraft.io/install/xjs/arch
---

[Canonical Snapcraft](https://snapcraft.io/)

# Install xjs on **Arch Linux**

# xjs

[Brandon Castillo (bran-castillo)](https://snapcraft.io/publisher/bran-castillo "View all snaps from Brandon Castillo (bran-castillo)")

* [Brandon Castillo (bran-castillo)](https://snapcraft.io/publisher/bran-castillo "View all snaps from Brandon Castillo (bran-castillo)")
* [Server and Cloud](https://snapcraft.io/search?categories=server-and-cloud)
* [Utilities](https://snapcraft.io/search?categories=utilities)

[Install](https://snapcraft.io/install/xjs/arch#install)

#### A tool to parse juju status yaml/json files offline

This eliminates the hassle of waiting for `juju status` in large environments.

**To use with Juju 2.x use the legacy/stable channel**

Installation

```
sudo snap install xjs
```

Usage

With yaml:

```
juju status --format yaml > juju-status.yaml
xjs juju-status.yaml
```

With json:

```
juju status --format json > juju-status.json
xjs juju-status.json
```

Options:

```
Usage: xjs [OPTIONS] <status files>

  xjs parses a juju status yaml/json and displays the information in a user
  friendly form highlighting specific fields of specific interest.

Options:
  --application <application name>
                                  Show only the application with the specified
                                  name
  --controller <controller name>  Show only the controller with the specified
                                  name
  -h, --hide-scale-zero           Hide applications with a scale of 0
  -s, --hide-subordinate-units    Hide subordinate units
  -c, --include-containers        Include Container information
  --machine <machine name>        Show only the machine with the specified
                                  name
  --model <model name>            Show only the model with the specified name
  --no-color                      Remove color from output
  -a, --show-apps                 Show application information
  -m, --show-machines             Show machine information
  -d, --show-model                Show model information
  -n, --show-net                  Show network interface information
  -u, --show-units                Show unit information
  --subordinate <subordinate name>
                                  Show only the subordinate unit with the
                                  specified name
  --unit <unit name>              Show only the unit with the specified name
  --help                          Show this message and exit.
```

### Package name

* xjs

---

### License

* GPL-3.0

---

### Last updated

* 4 June 2026 - latest/stable
* 12 June 2026 - latest/edge

---

### Websites

* [github.com/WizardBit/xjs](https://github.com/WizardBit/xjs "https://github.com/WizardBit/xjs")

---

### Donations

* [ubuntu.com](https://ubuntu.com/community/docs/contribute/donation "https://ubuntu.com/community/docs/contribute/donation")

---

### Source code

* [github.com/WizardBit/xjs](https://github.com/WizardBit/xjs "https://github.com/WizardBit/xjs")

---

### Report a bug

* [github.com/WizardBit/xjs/issues](https://github.com/WizardBit/xjs/issues "https://github.com/WizardBit/xjs/issues")

---

##### Report a Snap Store violation

* [Report this Snap](https://snapcraft.io/install/xjs/arch#report-snap-modal)

---

## Enable snaps on Arch Linux and install xjs

Snaps are applications packaged with all their dependencies to run on all popular Linux distributions from a single build. They update automatically and roll back gracefully.

Snaps are discoverable and installable from the [Snap Store](https://snapcraft.io/store), an app store with an audience of millions.

### Enable snapd

On Arch Linux, snap can be installed from the [Arch User Repository (AUR).](https://aur.archlinux.org/packages/snapd/)
The [manual build process](https://wiki.archlinux.org/index.php/Arch_User_Repository#Installing_packages) is the Arch-supported
install method for AUR packages, and you’ll need the [prerequisites](https://wiki.archlinux.org/index.php/Arch_User_Repository#Prerequisites)
installed before you can install any AUR package. You can then install snap with the following:

```
git clone https://aur.archlinux.org/snapd.git
cd snapd
makepkg -si
```

Once installed, the *systemd* unit that manages the main snap communication socket needs to be enabled:

```
sudo systemctl enable --now snapd.socket
```

If [AppArmor](https://wiki.archlinux.org/title/AppArmor) is enabled in your system, enable the service which loads AppArmor profiles for snaps:

```
sudo systemctl enable --now snapd.apparmor.service
```

To enable *classic* snap support, enter the following to create a symbolic link between `/var/lib/snapd/snap` and `/snap`:

```
sudo ln -s /var/lib/snapd/snap /snap
```

Either log out and back in again, or restart your system, to ensure snap’s paths are updated correctly.

### Install xjs

To install xjs, simply use the following command:

```
sudo snap install xjs
```

### Other popular snaps…

[See more...](https://snapcraft.io/search?categories=featured)

[See more in Featured](https://snapcraft.io/search?categories=featured)

### More things to do…

#### [Get the snap store](https://snapcraft.io/snap-store)

Browse and find snaps from the convenience of your desktop using the snap store snap.

#### [Learn more about snaps](https://snapcraft.io/docs)

Interested to find out more about snaps? Want to publish your own application? Visit [snapcraft.io](https://snapcraft.io/) now.

[Back to top](https://snapcraft.io/install/xjs/arch)

© 2026 Canonical Ltd.
Ubuntu and Canonical are registered trademarks of Canonical Ltd.

Powered by [Charmed Kubernetes](https://www.ubuntu.com/kubernetes)

[Join the forum](https://forum.snapcraft.io/), contribute to or report problems with,
[snapd](https://bugs.launchpad.net/snapd),
[Snapcraft](https://bugs.launchpad.net/snapcraft),
or [this site](https://github.com/canonical/snapcraft.io/issues/new).

* [Share on Twitter](https://twitter.com/snapcraftio)
* [Share on Facebook](https://www.facebook.com/snapcraftio)
* [Share on YouTube](https://www.youtube.com/snapcraftio)

* [Terms of Service](https://ubuntu.com/legal/terms-and-policies/snap-store-terms)
* [Data privacy](https://www.ubuntu.com/legal/data-privacy)
* [Manage your tracker settings](https://snapcraft.io/install/xjs/arch)
* [Service status](https://status.snapcraft.io/)
* [Other functions](https://dashboard.snapcraft.io/)
* [Contact us](https://snapcraft.io/about/contact-us)
